pub struct CommitCommand { /* private fields */ }Trait Implementations
Sourceimpl Command for CommitCommand
impl Command for CommitCommand
Sourceimpl Debug for CommitCommand
impl Debug for CommitCommand
Sourceimpl Default for CommitCommand
impl Default for CommitCommand
Sourcefn default() -> CommitCommand
fn default() -> CommitCommand
Returns the โdefault valueโ for a type. Read more
Sourceimpl StructOpt for CommitCommand
impl StructOpt for CommitCommand
Sourcefn from_clap(matches: &ArgMatches<'_>) -> Self
fn from_clap(matches: &ArgMatches<'_>) -> Self
Builds the struct from
clap::ArgMatches. Itโs guaranteed to succeed
if matches originates from an App generated by StructOpt::clap called on
the same type, otherwise it must panic.Sourcefn from_args() -> Selfwhere
Self: Sized,
fn from_args() -> Selfwhere
Self: Sized,
Builds the struct from the command line arguments (
std::env::args_os).
Calls clap::Error::exit on failure, printing the error message and aborting the program.Sourcefn from_args_safe() -> Result<Self, Error>where
Self: Sized,
fn from_args_safe() -> Result<Self, Error>where
Self: Sized,
Builds the struct from the command line arguments (
std::env::args_os).
Unlike StructOpt::from_args, returns clap::Error on failure instead of aborting the program,
so calling .exit is up to you.Sourcefn from_iter<I>(iter: I) -> Self
fn from_iter<I>(iter: I) -> Self
Gets the struct from any iterator such as a
Vec of your making.
Print the error message and quit the program in case of failure. Read moreAuto Trait Implementations
impl Freeze for CommitCommand
impl RefUnwindSafe for CommitCommand
impl Send for CommitCommand
impl Sync for CommitCommand
impl Unpin for CommitCommand
impl UnwindSafe for CommitCommand